@@ -45,9 +45,8 @@ private:
     template <int MAX_VAL>
     class randomLCG
     {
-#ifdef HAVE_CXX11
     static_assert((MAX_VAL != 0) && ((MAX_VAL & (MAX_VAL - 1)) == 0), "MAX_VAL must be a power of two");
-#endif
+
     private:
         uint32_t rand_seed;
 
@@ -68,16 +67,14 @@ public:
 
 public:
     /// Maximum number of supported SIDs
-    static const unsigned int MAX_SIDS = 3;
+    static constexpr unsigned int MAX_SIDS = 3;
+
+    static constexpr int_least32_t SCALE_FACTOR = 1 << 16;
 
-    static const int_least32_t SCALE_FACTOR = 1 << 16;
-#ifdef HAVE_CXX11
     static constexpr double SQRT_0_5 = 0.70710678118654746;
-#else
-#  define SQRT_0_5 0.70710678118654746
-#endif
-    static const int_least32_t C1 = static_cast<int_least32_t>(1.0 / (1.0 + SQRT_0_5) * SCALE_FACTOR);
-    static const int_least32_t C2 = static_cast<int_least32_t>(SQRT_0_5 / (1.0 + SQRT_0_5) * SCALE_FACTOR);
+
+    static constexpr int_least32_t C1 = static_cast<int_least32_t>(1.0 / (1.0 + SQRT_0_5) * SCALE_FACTOR);
+    static constexpr int_least32_t C2 = static_cast<int_least32_t>(SQRT_0_5 / (1.0 + SQRT_0_5) * SCALE_FACTOR);
 
 private:
     typedef int_least32_t (Mixer::*mixer_func_t)() const;
@@ -98,17 +95,17 @@ private:
     std::vector<mixer_func_t> m_mix;
     std::vector<scale_func_t> m_scale;
 
-    int m_oldRandomValue;
-    int m_fastForwardFactor;
+    int m_oldRandomValue = 0;
+    int m_fastForwardFactor = 1;
 
     // Mixer settings
-    short         *m_sampleBuffer;
-    uint_least32_t m_sampleCount;
-    uint_least32_t m_sampleIndex;
+    short         *m_sampleBuffer = nullptr;
+    uint_least32_t m_sampleCount = 0;
+    uint_least32_t m_sampleIndex = 0;
 
-    uint_least32_t m_sampleRate;
+    uint_least32_t m_sampleRate = 0;
 
-    bool m_stereo;
+    bool m_stereo = false;
 
     randomLCG<VOLUME_MAX> m_rand;
 
@@ -178,11 +175,6 @@ public:
      * Create a new mixer.
      */
     Mixer() :
-        m_oldRandomValue(0),
-        m_fastForwardFactor(1),
-        m_sampleCount(0),
-        m_sampleRate(0),
-        m_stereo(false),
         m_rand(257254)
     {
         m_mix.push_back(&Mixer::mono<1>);
